function f=getMinFreqaxis(maxf);
%% ===========================================================================
%getMinFreqaxis - Finds minimal set for frequency axis
%
% Parameter:    maxf	The max frequency to get
% Returns:      f	The minimum set of frequencies needed
%
% Example(s):
%
% Algorithmic details:
%
% Reference:
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 1998 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% Project       : FSAN duplex model
% Author(s)     : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%               : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: getMinFreqaxis.m,v 1.14 2000/11/13 14:53:32 tono Exp $
%% ===========================================================================
% Change History
%      1998-12-17 (Dab)  Created
%      1998-12-21 (ToNo) Added comments
%      1999-01-07 (Dab)  +/- 1e3 on every frequency point
%      1999-02-26 (ToNo) Added frequency points for cable model breakpoints
%      1999-08-12 (DaB)  Added 4.3 resolotion over ADSL band if ADSL is evaluated
%      1999-08-19 (DaB)  Updated for new tfplan structure
%      1999-09-30 (DaB)  Rewritten for new ex struct
%      2000-03-03 (GS)   Added support for SDSL
%      2000-09-22 (ToNo) Removed the 100Hz step stuff for SDSL
%% ===========================================================================
global ex;

if nargin<1,
    maxf=ex.param.frequency.max;
end

n=length(ex.tfplist);

f=[ex.param.frequency.min maxf];


for i=1:n,
    tmp=ex.tfplist(i).PSD.downstream;
    if strncmp(tmp,'calcPSD',7),
        start=findstr(tmp,'[');
        stop=findstr(tmp,']');
        tmp=str2num(tmp((start+1):(stop-1)));
        
        tmp=tmp(1:2:length(tmp));
        tmp2=tmp+1e3;
        tmp3=tmp-1e3;
        tmp2=union(tmp2,tmp3);
        tmp=union(tmp,tmp2);
        
        ind=find((tmp>0)&(tmp<maxf));
        tmp=tmp(ind);
        f=union(f,tmp);
        tmp2=tmp+1e3;
        tmp3=tmp-1e3;
        tmp2=union(tmp2,tmp3);
        tmp=union(tmp,tmp2);
    end;

    tmp=ex.tfplist(i).PSD.upstream;
    if strncmp(tmp,'calcPSD',7),
        start=findstr(tmp,'[');
        stop=findstr(tmp,']');
        tmp=str2num(tmp((start+1):(stop-1)));
        
        tmp=tmp(1:2:length(tmp));
        tmp2=tmp+1e3;
        tmp3=tmp-1e3;
        tmp2=union(tmp2,tmp3);
        tmp=union(tmp,tmp2);
        
        ind=find((tmp>0)&(tmp<maxf));
        tmp=tmp(ind);
        f=union(f,tmp);
        tmp2=tmp+1e3;
        tmp3=tmp-1e3;
        tmp2=union(tmp2,tmp3);
        f=union(f,tmp);   
    end;
end;

% Patch to fix ISDN PRA freq axis
tmp=[(150e3:150e3:30e6)];

% Patch to add cable model breakpoints
tmp=union(tmp,[0.5e6 5e6]);

% Patch to add ILoss test freq
TestFreq=0.5e6:0.5e6:ex.param.frequency.max;
tmp=union(tmp,TestFreq);

% patch to add ADSL breakpoints
tmp=union(tmp,[25.875e3 138e3 1.104e6]);

%if ex.param.testADSL,
tmp=union(tmp,[(4.3125:4.3125:1104)*1e3]);
%end;

% add all possible PSD intersection points between the main PSD 
% and the floor PSD for symmetric/asymmetric SDSL 
% (calculations based on Draft RE/TM_06011-2,Montreux 2000)
tmp=union(tmp,1e3.*[41.91 82.06 122.44 162.97 203.59 244.29 285.05 325.86...
		    366.72 407.61 448.55 489.52 530.51 571.53 612.57 645.72...
		    656.36 697.59 722.73 738.83 1194.48 1283.62]);
tmp=union(tmp,[115 150 200 250 275 300]*1e3); % The test frequencies for IL

% Extra for test
tmp=union(tmp,[40e3]);

f=union(f,tmp);
