function param = setupParam(vdslDuplex);
%% ===========================================================================
%setupParam - Sets up the experiment description structure for
% a certain FSAN duplex experiment.
%
% Parameter:    vdslDuplex	String describing vdsl duplex method under test
% Returns:      param		Structure describing the experiment parameters
%
% Example(s):
%   param = setupParam; 
%
% Algorithmic details:
%   Fill in the ex.param structure according to default parameters and input
%   parameters.
%
% Reference:
%    FSAN xDSL simulation tool manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 1998,99 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: setupParam.m,v 1.19 2001/05/10 10:07:27 tono Exp $
%% ===========================================================================
% Change History
%      1998-10-19 (ToNo) Created
%      1998-11-13 (ToNo) Splitted setup into three parts param,tfplan,tt
%      1998-12-08 (DaB)  updated
%      1998-12-11 (DaB)  Added HAM band on/off (1/0)
%      1998-12-16 (DaB)  Added re_calc_bg_noise on/off (1/0)
%      1998-12-21 (ToNo) Moved efficiencyLoss into TF plans
%      1998-12-22 (ToNo) Updated comments
%      1999-01-05 (ToNo) Changed how modem under test was defined and
%                        added the possibility of precalculated noise models
%      1999-01-07 (ToNo) removed the duplex stuff (replaced by gui.testADSL/gui.testVDSL)
%      1999-01-18 (ToNo) Added DefaultMaxf as maxfrequency was set in evalExp.
%      1999-02-04 (DaB)  Added XTlevel for NEXT,FEXT,3CXT
%      1999-02-05 (DaB)  Added modemlist parameter for anaylsed gui.modems in evalExperiment
%      1999-02-07 (ToNo) Modified list
%      1999-03-05 (ToNo) Renamed and modified hamband to use ITU-HAMBAND
%      1999-03-30 (DaB) Corrected thirdCXT value
%      1999-08-11 (DaB)  Added Zterm
%      1999-08-12 (DaB)  New structure for efficiencyLoss different for ADSL and VDSL
%      1999-08-25 (DaB)  Added alpha
%      1999-09-30 (DaB)  Rewritten for new ex struct
%      2000-04-06 (UvAn) Added new param; expNoise
%      2000-05-02 (ToNo) Removed defaultMaxf as it was not used
%% ===========================================================================

%% ===========================================================================
% System parameters
% Check arguments
if nargin<1,
        vdslDuplex='TBD';
end

frequency.fastrecalc      = 1;		% 1 if fast calaculations should
frequency.min             = 1;    	% Min frequency (Hz) to use
frequency.max             = 30e6;    	% Max frequency (Hz) to use 
frequency.granularity     = 1000;    	% Granularity (Hz) in the frequency domain 
% Derived parameters
frequency.f  = (frequency.min:frequency.granularity:frequency.max);
param.frequency=frequency;

param.expNoise            = -12;        % Exponent noise
param.backgroundNoise     = -140;	% Backgound noise (dBm/Hz)
param.XTlevel.NEXT        = -50;        % Reference value at 1MHz
param.XTlevel.NEXTslant   = 15;         % Slant of NEXT in dB/decade
param.XTlevel.FEXT        = -45;	% Reference value at 1MHz
param.XTlevel.FEXTslant   = 20;   	% Slant of FEXT in dB/decade
param.XTlevel.thirdCXT    = -75;        %         
param.Zterm               = 135;        % reference impedance for Attenuation calcualtion
param.modemlist           = ['VDSL'];                                        
param.HAMBandName         = 'ITU-HAMBAND';  % Name of hamband to use
param.FSANNoiseModel      = 'Calculate'; % FSAN model to use if not Calculate

tmp_xDSL.name='VDSL';
tmp_xDSL.used=vdslDuplex;
param.xDSLlist(1)=tmp_xDSL; 

