function tfplist = etsi_tfplansSDSL(tfplist);
%% ===========================================================================
% etsi_tfplansSDSL(tfplist) - Sets up the tfplan for ETSI SDSL
%
% Parameter:    tfplist	   Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = etsi_tfplanSDSL(ex.tfplist);    Add to existing tfplist
%   tfplan=getList(ex.tfplist,'SDSL-sym') ;      Get this SDSL plan
%
%   ex.tfplist = etsi_tfplanSDSL([]);            Create a new tfplist
%   tfplan=getList(ex.tfplist,'SDSL-sym');       Get this SDSL plan
%
% References:	Draft ETSI TS 101524-2 V1.1.1 (2000-05)
%    				FSAN duplex simulation memo, Telia 1999
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 1999 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% Project       : FSAN xDSL simulation tool
% Author(s)     : Tomas Nordstrom (Tomas.B.Nordstrom@Telia.se)
%               : Gernot Schmid (schmid@ftw.at)
%
% CVS:       $Id: etsi_tfplansSDSL.m,v 1.1 2000/11/10 10:18:25 tono Exp $
%% ===========================================================================
% Change History
%      2000-01-19 (GS) Created
%		 2000-09-27 (GS) Cleaning up for release
%      
%% ===========================================================================

% Default values
def_tfplan.name                  = 'N/A';
def_tfplan.PSD.downstream        = 'N/A';
def_tfplan.PSD.upstream          = 'N/A';
def_tfplan.PSD.active.upstream   = [5e3 2e6];
def_tfplan.PSD.active.downstream = [5e3 2e6];
def_tfplan.PSD.PBO.method        = 'None';	% Power back-off method (-=not applicable)
def_tfplan.PSD.PBO.param.len     = 1500;		% PBO parameter {length(m)}
def_tfplan.PSD.PBO.param.freq    = 2e6;	
def_tfplan.PSD.PBO.param.maxlen  = 1500;
def_tfplan.PSD.HAM.active        = 0;
def_tfplan.timeDivision.up       = 1;        % Time used in up resp. down lin
def_tfplan.timeDivision.down     = 1;
def_tfplan.timeDivision.sync     = 1;
def_tfplan.fixBitrate.name       = 'SDSL';
def_tfplan.fixBitrate.active     = 1;
def_tfplan.fixBitrate.param      = 'N/A';
def_tfplan.lcname                = 'N/A';


% SDSL default vaules
sdsl_tfplan=def_tfplan;
sdsl_tfplan.PSD.HAM.active        =0;



% SDSL TFPlan defintions
% --------------------------

% symmetric SDSL as specified in	Draft ETSI TS 101524-2 V1.1.1 (2000-05)
tmp_tfplan=sdsl_tfplan;
tmp_tfplan.name='SDSL-sym';
tmp_tfplan.lcname='SDSL-sym';
tmp_tfplan.PSD.downstream ='modelPSD_SDSL_sym(tfplan.lcname,ex.param.frequency.f)'; 
tmp_tfplan.PSD.upstream   = tmp_tfplan.PSD.downstream;	
tmp_tfplan.PSD.PBO.method='None'; 
tfplist=insertList(tfplist,tmp_tfplan);

% 	asymmetric SDSL as specified in Draft ETSI TS 101524-2 V1.1.1 (2000-05)
tmp_tfplan=sdsl_tfplan;
tmp_tfplan.name='SDSL-asym';
tmp_tfplan.lcname='SDSL-asym';
tmp_tfplan.PSD.downstream ='modelPSD_SDSL_asym(tfplan.lcname,ex.param.frequency.f,1)'; 
tmp_tfplan.PSD.upstream   ='modelPSD_SDSL_asym(tfplan.lcname,ex.param.frequency.f,2)';
tmp_tfplan.PSD.PBO.method='None'; 
tfplist=insertList(tfplist,tmp_tfplan);
